-- Plugin definitions.

local vim = vim
local Plug = vim.fn['plug#']
local config_path = vim.fn.stdpath('config') .. '/'

-- I have no idea how to auto-install vim-plug on Windows
-- so you will have to install it manually.
vim.cmd [[
	if !(has('win16') || has('win32') || has('win64'))
	  if empty(glob('~/.config/nvim/autoload/plug.vim'))
	    silent !curl -fLo ~/.config/nvim/autoload/plug.vim --create-dirs
	      \ https://raw.githubPlugrcontent.com/junegunn/vim-plug/master/plug.vim
	    autocmd VimEnter * PlugInstall | source %
	  endif
	endif
]]

vim.call('plug#begin', config_path .. 'plugged')

-- UI
Plug 'arcticicestudio/nord-vim'
Plug 'vim-airline/vim-airline'
Plug 'vim-airline/vim-airline-themes'
Plug 'ryanoasis/vim-devicons'
Plug('nvim-treesitter/nvim-treesitter', {['do'] = vim.fn[':TSUpdate']})

-- General Editing
Plug 'tpope/vim-surround'
Plug 'tpope/vim-commentary'

-- Search
Plug 'kien/ctrlp.vim'
Plug 'nvim-lua/plenary.nvim'
Plug('nvim-telescope/telescope.nvim', { tag = '0.1.2' })
Plug('nvim-telescope/telescope-fzf-native.nvim', {['do'] = 'make' })

-- Git
Plug 'tpope/vim-fugitive'

-- LSP
Plug('williamboman/mason.nvim', {['do'] = vim.fn[':MasonUpdate']})
Plug('williamboman/mason-lspconfig.nvim')
Plug('neovim/nvim-lspconfig')

-- Completion framework
Plug 'hrsh7th/nvim-cmp'
Plug 'hrsh7th/cmp-nvim-lsp'
Plug 'hrsh7th/cmp-nvim-lua'
Plug 'hrsh7th/cmp-nvim-lsp-signature-help'
Plug 'hrsh7th/cmp-vsnip'
Plug 'hrsh7th/cmp-path'
Plug 'hrsh7th/cmp-buffer'
Plug 'hrsh7th/vim-vsnip'

-- Tmux Helper
Plug 'preservim/vimux'
Plug 'christoomey/vim-tmux-navigator'

-- Linting
Plug 'w0rp/ale'

-- Planning
Plug 'jceb/vim-orgmode'

-- Commands
Plug 'skywind3000/asyncrun.vim'

-- Syntax highlighting
Plug 'sheerun/vim-polyglot'

-- Debugging
Plug 'puremourning/vimspector'

-- Languages

-------------------------
-- Python
-------------------------

-- Rust
Plug 'simrat39/rust-tools.nvim'

vim.call('plug#end')
